@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -145,18 +145,34 @@ public class FormatData_ru extends ListResourceBundle {
                "3-\u0439 \u043a\u0432.",
                "4-\u0439 \u043a\u0432.",
             };
-        final String[] metaValue_TimePatterns = new String[] {
-               "H:mm:ss zzzz",
-               "H:mm:ss z",
-               "H:mm:ss",
-               "H:mm",
-            };
-        final String[] metaValue_buddhist_QuarterNarrows = new String[] {
+        final String[] metaValue_QuarterNarrows = new String[] {
                "1",
                "2",
                "3",
                "4",
             };
+        final String[] metaValue_AmPmMarkers = new String[] {
+               "AM",
+               "PM",
+            };
+        final String[] metaValue_TimePatterns = new String[] {
+               "HH:mm:ss zzzz",
+               "HH:mm:ss z",
+               "HH:mm:ss",
+               "HH:mm",
+            };
+        final String[] metaValue_java_time_buddhist_long_Eras = new String[] {
+               "BC",
+               "\u0431\u0443\u0434\u0434\u0438\u0439\u0441\u043a\u0430\u044f \u044d\u0440\u0430",
+            };
+        final String[] metaValue_java_time_buddhist_Eras = new String[] {
+               "BC",
+               "BE",
+            };
+        final String[] metaValue_java_time_buddhist_narrow_Eras = new String[] {
+               "BC",
+               "\u0431\u044d",
+            };
         final String[] metaValue_java_time_buddhist_DatePatterns = new String[] {
                "EEEE, d MMMM y '\u0433'. G",
                "d MMMM y '\u0433'. G",
@@ -169,11 +185,39 @@ public class FormatData_ru extends ListResourceBundle {
                "d MMM y '\u0433'. GGGG",
                "dd.MM.y GGGG",
             };
-        final String[] metaValue_japanese_narrow_AmPmMarkers = new String[] {
-               "AM",
-               "PM",
+        final String[] metaValue_java_time_japanese_long_Eras = new String[] {
+               "\u043e\u0442 \u0420\u043e\u0436\u0434\u0435\u0441\u0442\u0432\u0430 \u0425\u0440\u0438\u0441\u0442\u043e\u0432\u0430",
+               "\u042d\u043f\u043e\u0445\u0430 \u041c\u044d\u0439\u0434\u0437\u0438",
+               "\u042d\u043f\u043e\u0445\u0430 \u0422\u0430\u0439\u0441\u044c\u043e",
+               "\u0421\u044c\u043e\u0432\u0430",
+               "\u042d\u043f\u043e\u0445\u0430 \u0425\u044d\u0439\u0441\u044d\u0439",
+               "\u0420\u044d\u0439\u0432\u0430",
             };
-        final String[] metaValue_islamic_Eras = new String[] {
+        final String[] metaValue_java_time_japanese_Eras = new String[] {
+               "\u043d. \u044d.",
+               "\u042d\u043f\u043e\u0445\u0430 \u041c\u044d\u0439\u0434\u0437\u0438",
+               "\u042d\u043f\u043e\u0445\u0430 \u0422\u0430\u0439\u0441\u044c\u043e",
+               "\u0421\u044c\u043e\u0432\u0430",
+               "\u042d\u043f\u043e\u0445\u0430 \u0425\u044d\u0439\u0441\u044d\u0439",
+               "\u0420\u044d\u0439\u0432\u0430",
+            };
+        final String[] metaValue_java_time_roc_long_Eras = new String[] {
+               "\u0434\u043e \u043e\u0441\u043d\u043e\u0432\u0430\u043d\u0438\u044f \u041a\u0438\u0442\u0430\u0439\u0441\u043a\u043e\u0439 \u0440\u0435\u0441\u043f\u0443\u0431\u043b\u0438\u043a\u0438",
+               "\u041c\u0438\u043d\u044c\u0433\u043e",
+            };
+        final String[] metaValue_java_time_roc_Eras = new String[] {
+               "Before R.O.C.",
+               "Minguo",
+            };
+        final String[] metaValue_java_time_roc_narrow_Eras = new String[] {
+               "\u0434\u043e \u0440\u0435\u0441\u043f.",
+               "\u041c\u0438\u043d\u044c\u0433\u043e",
+            };
+        final String[] metaValue_java_time_islamic_long_Eras = new String[] {
+               "",
+               "\u043f\u043e\u0441\u043b\u0435 \u0445\u0438\u0434\u0436\u0440\u044b",
+            };
+        final String[] metaValue_java_time_islamic_Eras = new String[] {
                "",
                "AH",
             };
@@ -182,42 +226,37 @@ public class FormatData_ru extends ListResourceBundle {
             { "MonthNames", metaValue_MonthNames },
             { "field.year", "\u0433\u043e\u0434" },
             { "calendarname.islamic-umalqura", "\u0438\u0441\u043b\u0430\u043c\u0441\u043a\u0438\u0439 \u043a\u0430\u043b\u0435\u043d\u0434\u0430\u0440\u044c (\u0423\u043c\u043c \u0430\u043b\u044c-\u041a\u0443\u0440\u0430)" },
-            { "buddhist.narrow.Eras",
-                new String[] {
-                    "BC",
-                    "\u0431\u044d",
-                }
-            },
+            { "japanese.AmPmMarkers", metaValue_AmPmMarkers },
+            { "buddhist.narrow.Eras", metaValue_java_time_buddhist_narrow_Eras },
+            { "AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.japanese.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "standalone.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "roc.QuarterNames", metaValue_QuarterNames },
             { "roc.MonthNarrows", metaValue_MonthNarrows },
             { "calendarname.islamic-civil", "\u0418\u0441\u043b\u0430\u043c\u0441\u043a\u0438\u0439 \u0433\u0440\u0430\u0436\u0434\u0430\u043d\u0441\u043a\u0438\u0439 \u043a\u0430\u043b\u0435\u043d\u0434\u0430\u0440\u044c" },
-            { "islamic.narrow.AmPmMarkers", metaValue_japanese_narrow_AmPmMarkers },
+            { "islamic.narrow.AmPmMarkers", metaValue_AmPmMarkers },
             { "japanese.TimePatterns", metaValue_TimePatterns },
+            { "roc.long.Eras", metaValue_java_time_roc_long_Eras },
             { "narrow.Eras",
                 new String[] {
                     "\u0434\u043e \u043d.\u044d.",
                     "\u043d.\u044d.",
                 }
             },
-            { "roc.long.Eras",
-                new String[] {
-                    "\u0434\u043e \u043e\u0441\u043d\u043e\u0432\u0430\u043d\u0438\u044f \u041a\u0438\u0442\u0430\u0439\u0441\u043a\u043e\u0439 \u0440\u0435\u0441\u043f\u0443\u0431\u043b\u0438\u043a\u0438",
-                    "\u041c\u0438\u043d\u044c\u0433\u043e",
-                }
-            },
             { "timezone.regionFormat.standard", "{0}, \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442\u043d\u043e\u0435 \u0432\u0440\u0435\u043c\u044f" },
+            { "japanese.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "calendarname.japanese", "\u044f\u043f\u043e\u043d\u0441\u043a\u0438\u0439 \u043a\u0430\u043b\u0435\u043d\u0434\u0430\u0440\u044c" },
             { "japanese.MonthNames", metaValue_MonthNames },
             { "standalone.DayAbbreviations", metaValue_DayAbbreviations },
             { "roc.MonthAbbreviations", metaValue_MonthAbbreviations },
+            { "java.time.islamic.narrow.Eras", metaValue_java_time_islamic_Eras },
             { "long.Eras",
                 new String[] {
                     "\u0434\u043e \u0420\u043e\u0436\u0434\u0435\u0441\u0442\u0432\u0430 \u0425\u0440\u0438\u0441\u0442\u043e\u0432\u0430",
                     "\u043e\u0442 \u0420\u043e\u0436\u0434\u0435\u0441\u0442\u0432\u0430 \u0425\u0440\u0438\u0441\u0442\u043e\u0432\u0430",
                 }
             },
+            { "roc.QuarterNarrows", metaValue_QuarterNarrows },
             { "islamic.DayNames", metaValue_DayNames },
             { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "buddhist.MonthNames", metaValue_MonthNames },
@@ -229,6 +268,7 @@ public class FormatData_ru extends ListResourceBundle {
                     "{1}, {0}",
                 }
             },
+            { "narrow.AmPmMarkers", metaValue_AmPmMarkers },
             { "latn.NumberElements",
                 new String[] {
                     ",",
@@ -248,17 +288,9 @@ public class FormatData_ru extends ListResourceBundle {
             { "japanese.DatePatterns", metaValue_buddhist_DatePatterns },
             { "buddhist.DayNames", metaValue_DayNames },
             { "field.minute", "\u043c\u0438\u043d\u0443\u0442\u0430" },
+            { "japanese.long.Eras", metaValue_java_time_japanese_long_Eras },
             { "field.era", "\u044d\u0440\u0430" },
-            { "japanese.long.Eras",
-                new String[] {
-                    "\u043e\u0442 \u0420\u043e\u0436\u0434\u0435\u0441\u0442\u0432\u0430 \u0425\u0440\u0438\u0441\u0442\u043e\u0432\u0430",
-                    "\u042d\u043f\u043e\u0445\u0430 \u041c\u044d\u0439\u0434\u0437\u0438",
-                    "\u042d\u043f\u043e\u0445\u0430 \u0422\u0430\u0439\u0441\u044c\u043e",
-                    "\u0421\u044c\u043e\u0432\u0430",
-                    "\u042d\u043f\u043e\u0445\u0430 \u0425\u044d\u0439\u0441\u044d\u0439",
-                    "",
-                }
-            },
+            { "buddhist.AmPmMarkers", metaValue_AmPmMarkers },
             { "field.dayperiod", "AM/PM" },
             { "standalone.MonthNarrows", metaValue_MonthNarrows },
             { "islamic.MonthNames",
@@ -278,30 +310,39 @@ public class FormatData_ru extends ListResourceBundle {
                     "",
                 }
             },
+            { "japanese.QuarterNarrows", metaValue_QuarterNarrows },
             { "calendarname.roc", "\u043a\u0430\u043b\u0435\u043d\u0434\u0430\u0440\u044c \u041c\u0438\u043d\u044c\u0433\u043e" },
             { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
-            { "islamic.Eras", metaValue_islamic_Eras },
+            { "islamic.Eras", metaValue_java_time_islamic_Eras },
             { "field.month", "\u043c\u0435\u0441\u044f\u0446" },
+            { "java.time.japanese.long.Eras", metaValue_java_time_japanese_long_Eras },
+            { "roc.Eras", metaValue_java_time_roc_Eras },
             { "field.second", "\u0441\u0435\u043a\u0443\u043d\u0434\u0430" },
-            { "roc.Eras",
+            { "islamic.MonthNarrows",
                 new String[] {
-                    "Before R.O.C.",
-                    "Minguo",
+                    "1",
+                    "2",
+                    "3",
+                    "4",
+                    "5",
+                    "6",
+                    "7",
+                    "8",
+                    "9",
+                    "10",
+                    "11",
+                    "12",
+                    "",
                 }
             },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayAbbreviations },
-            { "NumberPatterns",
-                new String[] {
-                    "#,##0.###",
-                    "#,##0.00\u00a0\u00a4",
-                    "#,##0\u00a0%",
-                }
-            },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "\u0438\u0441\u043b\u0430\u043c\u0441\u043a\u0438\u0439 \u043a\u0430\u043b\u0435\u043d\u0434\u0430\u0440\u044c" },
-            { "japanese.narrow.AmPmMarkers", metaValue_japanese_narrow_AmPmMarkers },
+            { "java.time.roc.long.Eras", metaValue_java_time_roc_long_Eras },
+            { "java.time.roc.narrow.Eras", metaValue_java_time_roc_narrow_Eras },
+            { "japanese.narrow.AmPmMarkers", metaValue_AmPmMarkers },
             { "buddhist.TimePatterns", metaValue_TimePatterns },
             { "standalone.MonthAbbreviations",
                 new String[] {
@@ -325,26 +366,27 @@ public class FormatData_ru extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0 \u0442\u044b\u0441\u044f\u0447\u0430",
-                    "00 \u0442\u044b\u0441\u044f\u0447\u0430",
-                    "000 \u0442\u044b\u0441\u044f\u0447\u0430",
-                    "0 \u043c\u0438\u043b\u043b\u0438\u043e\u043d",
-                    "00 \u043c\u0438\u043b\u043b\u0438\u043e\u043d",
-                    "000 \u043c\u0438\u043b\u043b\u0438\u043e\u043d",
-                    "0 \u043c\u0438\u043b\u043b\u0438\u0430\u0440\u0434",
-                    "00 \u043c\u0438\u043b\u043b\u0438\u0430\u0440\u0434",
-                    "000 \u043c\u0438\u043b\u043b\u0438\u0430\u0440\u0434",
-                    "0 \u0442\u0440\u0438\u043b\u043b\u0438\u043e\u043d",
-                    "00 \u0442\u0440\u0438\u043b\u043b\u0438\u043e\u043d",
-                    "000 \u0442\u0440\u0438\u043b\u043b\u0438\u043e\u043d",
+                    "{one:0' '\u0442\u044b\u0441\u044f\u0447\u0430 few:0' '\u0442\u044b\u0441\u044f\u0447\u0438 many:0' '\u0442\u044b\u0441\u044f\u0447 other:0' '\u0442\u044b\u0441\u044f\u0447\u0438}",
+                    "{one:00' '\u0442\u044b\u0441\u044f\u0447\u0430 few:00' '\u0442\u044b\u0441\u044f\u0447\u0438 many:00' '\u0442\u044b\u0441\u044f\u0447 other:00' '\u0442\u044b\u0441\u044f\u0447\u0438}",
+                    "{one:000' '\u0442\u044b\u0441\u044f\u0447\u0430 few:000' '\u0442\u044b\u0441\u044f\u0447\u0438 many:000' '\u0442\u044b\u0441\u044f\u0447 other:000' '\u0442\u044b\u0441\u044f\u0447\u0438}",
+                    "{one:0' '\u043c\u0438\u043b\u043b\u0438\u043e\u043d few:0' '\u043c\u0438\u043b\u043b\u0438\u043e\u043d\u0430 many:0' '\u043c\u0438\u043b\u043b\u0438\u043e\u043d\u043e\u0432 other:0' '\u043c\u0438\u043b\u043b\u0438\u043e\u043d\u0430}",
+                    "{one:00' '\u043c\u0438\u043b\u043b\u0438\u043e\u043d few:00' '\u043c\u0438\u043b\u043b\u0438\u043e\u043d\u0430 many:00' '\u043c\u0438\u043b\u043b\u0438\u043e\u043d\u043e\u0432 other:00' '\u043c\u0438\u043b\u043b\u0438\u043e\u043d\u0430}",
+                    "{one:000' '\u043c\u0438\u043b\u043b\u0438\u043e\u043d few:000' '\u043c\u0438\u043b\u043b\u0438\u043e\u043d\u0430 many:000' '\u043c\u0438\u043b\u043b\u0438\u043e\u043d\u043e\u0432 other:000' '\u043c\u0438\u043b\u043b\u0438\u043e\u043d\u0430}",
+                    "{one:0' '\u043c\u0438\u043b\u043b\u0438\u0430\u0440\u0434 few:0' '\u043c\u0438\u043b\u043b\u0438\u0430\u0440\u0434\u0430 many:0' '\u043c\u0438\u043b\u043b\u0438\u0430\u0440\u0434\u043e\u0432 other:0' '\u043c\u0438\u043b\u043b\u0438\u0430\u0440\u0434\u0430}",
+                    "{one:00' '\u043c\u0438\u043b\u043b\u0438\u0430\u0440\u0434 few:00' '\u043c\u0438\u043b\u043b\u0438\u0430\u0440\u0434\u0430 many:00' '\u043c\u0438\u043b\u043b\u0438\u0430\u0440\u0434\u043e\u0432 other:00' '\u043c\u0438\u043b\u043b\u0438\u0430\u0440\u0434\u0430}",
+                    "{one:000' '\u043c\u0438\u043b\u043b\u0438\u0430\u0440\u0434 few:000' '\u043c\u0438\u043b\u043b\u0438\u0430\u0440\u0434\u0430 many:000' '\u043c\u0438\u043b\u043b\u0438\u0430\u0440\u0434\u043e\u0432 other:000' '\u043c\u0438\u043b\u043b\u0438\u0430\u0440\u0434\u0430}",
+                    "{one:0' '\u0442\u0440\u0438\u043b\u043b\u0438\u043e\u043d few:0' '\u0442\u0440\u0438\u043b\u043b\u0438\u043e\u043d\u0430 many:0' '\u0442\u0440\u0438\u043b\u043b\u0438\u043e\u043d\u043e\u0432 other:0' '\u0442\u0440\u0438\u043b\u043b\u0438\u043e\u043d\u0430}",
+                    "{one:00' '\u0442\u0440\u0438\u043b\u043b\u0438\u043e\u043d few:00' '\u0442\u0440\u0438\u043b\u043b\u0438\u043e\u043d\u0430 many:00' '\u0442\u0440\u0438\u043b\u043b\u0438\u043e\u043d\u043e\u0432 other:00' '\u0442\u0440\u0438\u043b\u043b\u0438\u043e\u043d\u0430}",
+                    "{one:000' '\u0442\u0440\u0438\u043b\u043b\u0438\u043e\u043d few:000' '\u0442\u0440\u0438\u043b\u043b\u0438\u043e\u043d\u0430 many:000' '\u0442\u0440\u0438\u043b\u043b\u0438\u043e\u043d\u043e\u0432 other:000' '\u0442\u0440\u0438\u043b\u043b\u0438\u043e\u043d\u0430}",
                 }
             },
-            { "buddhist.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
-            { "roc.narrow.AmPmMarkers", metaValue_japanese_narrow_AmPmMarkers },
+            { "buddhist.QuarterNarrows", metaValue_QuarterNarrows },
+            { "roc.narrow.AmPmMarkers", metaValue_AmPmMarkers },
             { "standalone.QuarterNames", metaValue_QuarterNames },
             { "japanese.MonthNarrows", metaValue_MonthNarrows },
             { "islamic.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "roc.DayAbbreviations", metaValue_DayAbbreviations },
+            { "java.time.buddhist.long.Eras", metaValue_java_time_buddhist_long_Eras },
             { "standalone.DayNarrows",
                 new String[] {
                     "\u0412",
@@ -356,23 +398,16 @@ public class FormatData_ru extends ListResourceBundle {
                     "\u0421",
                 }
             },
-            { "islamic.AmPmMarkers", metaValue_japanese_narrow_AmPmMarkers },
-            { "buddhist.long.Eras",
-                new String[] {
-                    "BC",
-                    "\u0431\u0443\u0434\u0434\u0438\u0439\u0441\u043a\u0430\u044f \u044d\u0440\u0430",
-                }
-            },
+            { "islamic.AmPmMarkers", metaValue_AmPmMarkers },
+            { "buddhist.long.Eras", metaValue_java_time_buddhist_long_Eras },
             { "TimePatterns", metaValue_TimePatterns },
             { "islamic.DayNarrows", metaValue_DayAbbreviations },
+            { "java.time.roc.Eras", metaValue_java_time_roc_Eras },
             { "field.zone", "\u0447\u0430\u0441\u043e\u0432\u043e\u0439 \u043f\u043e\u044f\u0441" },
             { "japanese.QuarterAbbreviations", metaValue_QuarterAbbreviations },
-            { "roc.narrow.Eras",
-                new String[] {
-                    "\u0434\u043e \u0440\u0435\u0441\u043f.",
-                    "\u041c\u0438\u043d\u044c\u0433\u043e",
-                }
-            },
+            { "roc.narrow.Eras", metaValue_java_time_roc_narrow_Eras },
+            { "buddhist.narrow.AmPmMarkers", metaValue_AmPmMarkers },
+            { "buddhist.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "Eras",
                 new String[] {
                     "\u0434\u043e \u043d. \u044d.",
@@ -381,35 +416,30 @@ public class FormatData_ru extends ListResourceBundle {
             },
             { "roc.DayNames", metaValue_DayNames },
             { "islamic.QuarterNames", metaValue_QuarterNames },
+            { "QuarterNarrows", metaValue_QuarterNarrows },
+            { "islamic.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.islamic.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "field.weekday", "\u0434\u0435\u043d\u044c \u043d\u0435\u0434\u0435\u043b\u0438" },
             { "japanese.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "islamic.DayAbbreviations", metaValue_DayAbbreviations },
-            { "islamic.long.Eras",
-                new String[] {
-                    "",
-                    "\u043f\u043e\u0441\u043b\u0435 \u0445\u0438\u0434\u0436\u0440\u044b",
-                }
-            },
+            { "islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
+            { "java.time.islamic.Eras", metaValue_java_time_islamic_Eras },
             { "japanese.QuarterNames", metaValue_QuarterNames },
             { "buddhist.QuarterAbbreviations", metaValue_QuarterAbbreviations },
+            { "java.time.buddhist.Eras", metaValue_java_time_buddhist_Eras },
             { "japanese.DayNames", metaValue_DayNames },
             { "japanese.DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNames", metaValue_DayNames },
             { "buddhist.DatePatterns", metaValue_buddhist_DatePatterns },
+            { "java.time.japanese.Eras", metaValue_java_time_japanese_Eras },
             { "roc.MonthNames", metaValue_MonthNames },
-            { "buddhist.Eras",
-                new String[] {
-                    "BC",
-                    "BE",
-                }
-            },
+            { "buddhist.Eras", metaValue_java_time_buddhist_Eras },
             { "field.week", "\u043d\u0435\u0434\u0435\u043b\u044f" },
             { "buddhist.MonthNarrows", metaValue_MonthNarrows },
             { "buddhist.QuarterNames", metaValue_QuarterNames },
-            { "islamic.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
+            { "islamic.QuarterNarrows", metaValue_QuarterNarrows },
             { "roc.DayNarrows", metaValue_DayAbbreviations },
-            { "roc.AmPmMarkers", metaValue_japanese_narrow_AmPmMarkers },
+            { "roc.AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.roc.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "java.time.buddhist.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "short.CompactNumberPatterns",
@@ -417,21 +447,22 @@ public class FormatData_ru extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0\u00a0\u0442\u044b\u0441'.'",
-                    "00\u00a0\u0442\u044b\u0441'.'",
-                    "000\u00a0\u0442\u044b\u0441'.'",
-                    "0\u00a0\u043c\u043b\u043d",
-                    "00\u00a0\u043c\u043b\u043d",
-                    "000\u00a0\u043c\u043b\u043d",
-                    "0\u00a0\u043c\u043b\u0440\u0434",
-                    "00\u00a0\u043c\u043b\u0440\u0434",
-                    "000\u00a0\u043c\u043b\u0440\u0434",
-                    "0\u00a0\u0442\u0440\u043b\u043d",
-                    "00\u00a0\u0442\u0440\u043b\u043d",
-                    "000\u00a0\u0442\u0440\u043b\u043d",
+                    "{one:0\u00a0\u0442\u044b\u0441'.' few:0\u00a0\u0442\u044b\u0441'.' many:0\u00a0\u0442\u044b\u0441'.' other:0\u00a0\u0442\u044b\u0441'.'}",
+                    "{one:00\u00a0\u0442\u044b\u0441'.' few:00\u00a0\u0442\u044b\u0441'.' many:00\u00a0\u0442\u044b\u0441'.' other:00\u00a0\u0442\u044b\u0441'.'}",
+                    "{one:000\u00a0\u0442\u044b\u0441'.' few:000\u00a0\u0442\u044b\u0441'.' many:000\u00a0\u0442\u044b\u0441'.' other:000\u00a0\u0442\u044b\u0441'.'}",
+                    "{one:0\u00a0\u043c\u043b\u043d few:0\u00a0\u043c\u043b\u043d many:0\u00a0\u043c\u043b\u043d other:0\u00a0\u043c\u043b\u043d}",
+                    "{one:00\u00a0\u043c\u043b\u043d few:00\u00a0\u043c\u043b\u043d many:00\u00a0\u043c\u043b\u043d other:00\u00a0\u043c\u043b\u043d}",
+                    "{one:000\u00a0\u043c\u043b\u043d few:000\u00a0\u043c\u043b\u043d many:000\u00a0\u043c\u043b\u043d other:000\u00a0\u043c\u043b\u043d}",
+                    "{one:0\u00a0\u043c\u043b\u0440\u0434 few:0\u00a0\u043c\u043b\u0440\u0434 many:0\u00a0\u043c\u043b\u0440\u0434 other:0\u00a0\u043c\u043b\u0440\u0434}",
+                    "{one:00\u00a0\u043c\u043b\u0440\u0434 few:00\u00a0\u043c\u043b\u0440\u0434 many:00\u00a0\u043c\u043b\u0440\u0434 other:00\u00a0\u043c\u043b\u0440\u0434}",
+                    "{one:000\u00a0\u043c\u043b\u0440\u0434 few:000\u00a0\u043c\u043b\u0440\u0434 many:000\u00a0\u043c\u043b\u0440\u0434 other:000\u00a0\u043c\u043b\u0440\u0434}",
+                    "{one:0\u00a0\u0442\u0440\u043b\u043d few:0\u00a0\u0442\u0440\u043b\u043d many:0\u00a0\u0442\u0440\u043b\u043d other:0\u00a0\u0442\u0440\u043b\u043d}",
+                    "{one:00\u00a0\u0442\u0440\u043b\u043d few:00\u00a0\u0442\u0440\u043b\u043d many:00\u00a0\u0442\u0440\u043b\u043d other:00\u00a0\u0442\u0440\u043b\u043d}",
+                    "{one:000\u00a0\u0442\u0440\u043b\u043d few:000\u00a0\u0442\u0440\u043b\u043d many:000\u00a0\u0442\u0440\u043b\u043d other:000\u00a0\u0442\u0440\u043b\u043d}",
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
+            { "java.time.buddhist.narrow.Eras", metaValue_java_time_buddhist_narrow_Eras },
             { "timezone.regionFormat.daylight", "{0}, \u043b\u0435\u0442\u043d\u0435\u0435 \u0432\u0440\u0435\u043c\u044f" },
             { "DatePatterns",
                 new String[] {
@@ -463,7 +494,7 @@ public class FormatData_ru extends ListResourceBundle {
                     "",
                 }
             },
-            { "islamic.narrow.Eras", metaValue_islamic_Eras },
+            { "islamic.narrow.Eras", metaValue_java_time_islamic_Eras },
             { "calendarname.buddhist", "\u0431\u0443\u0434\u0434\u0438\u0439\u0441\u043a\u0438\u0439 \u043a\u0430\u043b\u0435\u043d\u0434\u0430\u0440\u044c" },
             { "standalone.MonthNames",
                 new String[] {
@@ -482,21 +513,22 @@ public class FormatData_ru extends ListResourceBundle {
                     "",
                 }
             },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "#,##0.00\u00a0\u00a4",
+                    "#,##0\u00a0%",
+                    "#,##0.00\u00a0\u00a4",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayAbbreviations },
+            { "java.time.islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.DayNarrows", metaValue_DayAbbreviations },
             { "QuarterNames", metaValue_QuarterNames },
             { "roc.TimePatterns", metaValue_TimePatterns },
             { "QuarterAbbreviations", metaValue_QuarterAbbreviations },
-            { "japanese.Eras",
-                new String[] {
-                    "\u043d. \u044d.",
-                    "\u042d\u043f\u043e\u0445\u0430 \u041c\u044d\u0439\u0434\u0437\u0438",
-                    "\u042d\u043f\u043e\u0445\u0430 \u0422\u0430\u0439\u0441\u044c\u043e",
-                    "\u0421\u044c\u043e\u0432\u0430",
-                    "\u042d\u043f\u043e\u0445\u0430 \u0425\u044d\u0439\u0441\u044d\u0439",
-                    "",
-                }
-            },
+            { "japanese.Eras", metaValue_java_time_japanese_Eras },
+            { "roc.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "calendarname.gregory", metaValue_calendarname_gregorian },
         };
         return data;
